==> qtjambi-quick-debuginfo-macos-5.15.17.jar: sources/QtJambiQuick/QQuickWindow_GraphicsStateInfo_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQuick/qquickwindow.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiQuick/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QQuickWindow_GraphicsStateInfo(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQuickWindow::GraphicsStateInfo")
    QQuickWindow::GraphicsStateInfo *_ptr = reinterpret_cast<QQuickWindow::GraphicsStateInfo *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QQuickWindow_GraphicsStateInfo_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QQuickWindow::GraphicsStateInfo *__qt_this = new(__qtjambi_ptr) QQuickWindow::GraphicsStateInfo();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QQuickWindow::GraphicsStateInfo
void __qt_destruct_QQuickWindow_GraphicsStateInfo(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQuickWindow::GraphicsStateInfo")
    reinterpret_cast<QQuickWindow::GraphicsStateInfo*>(ptr)->~GraphicsStateInfo();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQuickWindow::GraphicsStateInfo::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickWindow_00024GraphicsStateInfo_initialize_1native__Lio_qt_quick_QQuickWindow_00024GraphicsStateInfo_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQuickWindow::GraphicsStateInfo::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQuickWindow_GraphicsStateInfo_0, sizeof(QQuickWindow::GraphicsStateInfo), typeid(QQuickWindow::GraphicsStateInfo), false, &deleter_QQuickWindow_GraphicsStateInfo, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QQuickWindow::GraphicsStateInfo::operator==(QQuickWindow::GraphicsStateInfo,QQuickWindow::GraphicsStateInfo)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickWindow_00024GraphicsStateInfo_operator_1equal_1native_1cref_1QQuickWindow_1GraphicsStateInfo__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QQuickWindow::GraphicsStateInfo *__qt_this = QtJambiAPI::objectFromNativeId<QQuickWindow::GraphicsStateInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQuickWindow::GraphicsStateInfo::operator==(QQuickWindow::GraphicsStateInfo,QQuickWindow::GraphicsStateInfo)", __qt_this)
        const QQuickWindow::GraphicsStateInfo& __qt_value21 = QtJambiAPI::valueReferenceFromNativeId<QQuickWindow::GraphicsStateInfo>(value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickWindow_00024GraphicsStateInfo_setCurrentFrameSlot_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint currentFrameSlot0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuickWindow::GraphicsStateInfo *__qt_this = QtJambiAPI::objectFromNativeId<QQuickWindow::GraphicsStateInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->currentFrameSlot = static_cast<int>(currentFrameSlot0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickWindow_00024GraphicsStateInfo_currentFrameSlot_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuickWindow::GraphicsStateInfo *__qt_this = QtJambiAPI::objectFromNativeId<QQuickWindow::GraphicsStateInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->currentFrameSlot;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickWindow_00024GraphicsStateInfo_setFramesInFlight_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint framesInFlight0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuickWindow::GraphicsStateInfo *__qt_this = QtJambiAPI::objectFromNativeId<QQuickWindow::GraphicsStateInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->framesInFlight = static_cast<int>(framesInFlight0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickWindow_00024GraphicsStateInfo_framesInFlight_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuickWindow::GraphicsStateInfo *__qt_this = QtJambiAPI::objectFromNativeId<QQuickWindow::GraphicsStateInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->framesInFlight;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickWindow_00024GraphicsStateInfo_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QQuickWindow::GraphicsStateInfo *__qt_this = QtJambiAPI::objectFromNativeId<QQuickWindow::GraphicsStateInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickWindow_00024GraphicsStateInfo_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QQuickWindow::GraphicsStateInfo *__qt_this = QtJambiAPI::objectFromNativeId<QQuickWindow::GraphicsStateInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QQuickWindow_GraphicsStateInfo(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QQuickWindow::GraphicsStateInfo>("QQuickWindow::GraphicsStateInfo", "io/qt/quick/QQuickWindow$GraphicsStateInfo");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QQuickWindow_GraphicsStateInfo, {
        ConstructorInfo(&__qt_construct_QQuickWindow_GraphicsStateInfo_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQuickWindow_GraphicsStateInfo);
    registerMetaType<QQuickWindow::GraphicsStateInfo>("QQuickWindow::GraphicsStateInfo");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-quick-debuginfo-macos-5.15.18.jar: sources/QtJambiQuick/QQuickWindow_GraphicsStateInfo_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQuick/qquickwindow.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiQuick/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QQuickWindow_GraphicsStateInfo(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQuickWindow::GraphicsStateInfo")
    QQuickWindow::GraphicsStateInfo *_ptr = reinterpret_cast<QQuickWindow::GraphicsStateInfo *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QQuickWindow_GraphicsStateInfo_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QQuickWindow::GraphicsStateInfo *__qt_this = new(__qtjambi_ptr) QQuickWindow::GraphicsStateInfo();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QQuickWindow::GraphicsStateInfo
void __qt_destruct_QQuickWindow_GraphicsStateInfo(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQuickWindow::GraphicsStateInfo")
    reinterpret_cast<QQuickWindow::GraphicsStateInfo*>(ptr)->~GraphicsStateInfo();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQuickWindow::GraphicsStateInfo::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickWindow_00024GraphicsStateInfo_initialize_1native__Lio_qt_quick_QQuickWindow_00024GraphicsStateInfo_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQuickWindow::GraphicsStateInfo::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQuickWindow_GraphicsStateInfo_0, sizeof(QQuickWindow::GraphicsStateInfo), typeid(QQuickWindow::GraphicsStateInfo), false, &deleter_QQuickWindow_GraphicsStateInfo, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QQuickWindow::GraphicsStateInfo::operator==(QQuickWindow::GraphicsStateInfo,QQuickWindow::GraphicsStateInfo)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickWindow_00024GraphicsStateInfo_equals_1native_1cref_1QQuickWindow_1GraphicsStateInfo__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QQuickWindow::GraphicsStateInfo *__qt_this = QtJambiAPI::objectFromNativeId<QQuickWindow::GraphicsStateInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQuickWindow::GraphicsStateInfo::operator==(QQuickWindow::GraphicsStateInfo,QQuickWindow::GraphicsStateInfo)", __qt_this)
        const QQuickWindow::GraphicsStateInfo& __qt_value21 = QtJambiAPI::valueReferenceFromNativeId<QQuickWindow::GraphicsStateInfo>(value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickWindow_00024GraphicsStateInfo_setCurrentFrameSlot_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint currentFrameSlot0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuickWindow::GraphicsStateInfo *__qt_this = QtJambiAPI::objectFromNativeId<QQuickWindow::GraphicsStateInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->currentFrameSlot = static_cast<int>(currentFrameSlot0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickWindow_00024GraphicsStateInfo_currentFrameSlot_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuickWindow::GraphicsStateInfo *__qt_this = QtJambiAPI::objectFromNativeId<QQuickWindow::GraphicsStateInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->currentFrameSlot;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickWindow_00024GraphicsStateInfo_setFramesInFlight_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint framesInFlight0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuickWindow::GraphicsStateInfo *__qt_this = QtJambiAPI::objectFromNativeId<QQuickWindow::GraphicsStateInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->framesInFlight = static_cast<int>(framesInFlight0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickWindow_00024GraphicsStateInfo_framesInFlight_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuickWindow::GraphicsStateInfo *__qt_this = QtJambiAPI::objectFromNativeId<QQuickWindow::GraphicsStateInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->framesInFlight;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickWindow_00024GraphicsStateInfo_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QQuickWindow::GraphicsStateInfo *__qt_this = QtJambiAPI::objectFromNativeId<QQuickWindow::GraphicsStateInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickWindow_00024GraphicsStateInfo_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QQuickWindow::GraphicsStateInfo *__qt_this = QtJambiAPI::objectFromNativeId<QQuickWindow::GraphicsStateInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QQuickWindow_GraphicsStateInfo(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QQuickWindow::GraphicsStateInfo>("QQuickWindow::GraphicsStateInfo", "io/qt/quick/QQuickWindow$GraphicsStateInfo");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QQuickWindow_GraphicsStateInfo, {
        ConstructorInfo(&__qt_construct_QQuickWindow_GraphicsStateInfo_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQuickWindow_GraphicsStateInfo);
    registerMetaType<QQuickWindow::GraphicsStateInfo>("QQuickWindow::GraphicsStateInfo");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
